@@ -5,7 +5,7 @@ package Data::Scan;
 
 # ABSTRACT: Stackfree arbitrary data scanner
 
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 our $AUTHORITY = 'cpan:JDDPAUSE'; # AUTHORITY
 
@@ -38,7 +38,7 @@ sub process {
   #
   # Start
   #
-  $consumer->dsstart();
+  $consumer->dsstart(@_);
   #
   # Loop
   #
@@ -81,7 +81,7 @@ Data::Scan - Stackfree arbitrary data scanner
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -116,9 +116,9 @@ Scan over all items in @arguments and will call the consumer with these five met
 
 =over
 
-=item $consumer->dsstart()
+=item $consumer->dsstart(Any @arguments)
 
-Indicates to the consumer that scanning is starting. Return value is ignored.
+Indicates to the consumer that scanning is starting. All initial arguments are sent to this method. Return value is ignored.
 
 =item $consumer->dsopen(Any $item)
 
